@@ -44,6 +44,7 @@ API_PATH = {
     "activity_move": "api/activities/{activity_id}/move_activity",
     "activities_bulk_clone": "api/activities/bulk_clone",
     "activities_bulk_update": "api/activities/bulk_update",
+    "clone_widgets": "api/activities/{activity_from_id}/clone_widgets_from/{activity_to_id}",
     "widgets_config": "api/widget_config.json",
     "widget_config": "api/widget_config/{widget_config_id}.json",
     "services": "api/services.json",
@@ -86,7 +87,9 @@ API_PATH = {
     "parts_bulk_create": "/api/v3/parts/bulk_create_part_instances",
     "parts_bulk_delete": "/api/v3/parts/bulk_delete_part_instances",
     "parts_export": "api/v3/parts/export",
+    'parts_import': 'api/v3/parts/import_parts',
     "part": "api/v3/parts/{part_id}.json",
+    "order_properties": "api/v3/parts/{part_id}/order_properties",
     "properties": "api/v3/properties.json",
     "properties_bulk_update": "api/v3/properties/bulk_update",
     "properties_create_model": "api/v3/properties/create_model",
