@@ -134,7 +134,6 @@ class AttachmentProperty(Property):
         self._upload(data)
         self._value = name
 
-    # custom for PIM2
     def _download(self, **kwargs):
         url = self._client._build_url("property_download", property_id=self.id)
         request_params = dict()
@@ -148,12 +147,14 @@ class AttachmentProperty(Property):
 
         return response
 
-    # custom for PIM2
     def _upload(self, data):
         url = self._client._build_url("property_upload", property_id=self.id)
 
         response = self._client._request(
-            "POST", url, data={"part": self._json_data["part_id"]}, files={"attachment": data}
+            "POST",
+            url,
+            data={"part": self._json_data["part_id"]},
+            files={"attachment": data},
         )
 
         if response.status_code != requests.codes.ok:  # pragma: no cover
