@@ -1,57 +1,56 @@
 from unittest import TestCase
 
-from pykechain.utils import is_url, is_valid_email, Empty, get_in_chunks
-from tests.classes import SixTestCase
+from pykechain.utils import Empty, get_in_chunks, is_url, is_valid_email
 
 
-class TestIsURL(SixTestCase):
+class TestIsURL(TestCase):
     def test_is_url_returns_true_on_valid_url(self):
         addresses = [
-            u"http://foobar.dk",
-            u"http://foobar.museum/foobar",
-            u"http://fo.com",
-            u"http://FOO.com",
-            u"http://foo.com/blah_blah",
-            u"http://foo.com/blah_blah/",
-            u"http://foo.com/blah_blah_(wikipedia)",
-            u"http://foo.com/blah_blah_(wikipedia)_(again)",
-            u"http://www.example.com/wpstyle/?p=364",
-            u"https://www.example.com/foo/?bar=baz&inga=42&quux",
-            u"https://www.example.com?bar=baz",
-            u"http://✪df.ws/123",
-            u"http://userid:password@example.com:8080",
-            u"http://userid@example.com",
-            u"http://userid@example.com:8080/",
-            u"http://userid:password@example.com",
-            u"http://142.42.1.1/",
-            u"http://142.42.1.1:8080/",
-            u"http://⌘.ws/",
-            u"http://foo.com/blah_(wikipedia)#cite-1",
-            u"http://foo.com/unicode_(✪)_in_parens",
-            u"http://foo.com/(something)?after=parens",
-            u"http://☺.damowmow.com/",
-            u"http://code.google.com/events/#&product=browser",
-            u"http://j.mp",
-            u"ftp://foo.bar/baz",
-            u"http://foo.bar/?q=Test%20URL-encoded%20stuff",
-            u"http://-.~_!$&'()*+,;=:%40:80%2f::::::@example.com",
-            u"http://1337.net",
-            u"http://a.b-c.de",
-            u"http://223.255.255.254",
-            u"http://127.0.10.150",
-            u"http://localhost",
-            u"http://localhost:8000",
-            u"http://[FEDC:BA98:7654:3210:FEDC:BA98:7654:3210]:80/index.html",
-            u"http://[1080:0:0:0:8:800:200C:417A]/index.html",
-            u"http://[3ffe:2a00:100:7031::1]",
-            u"http://[1080::8:800:200C:417A]/foo",
-            u"http://[::192.9.5.5]/ipng",
-            u"http://[::FFFF:129.144.52.38]:80/index.html",
-            u"http://[2010:836B:4179::836B:4179]",
+            "http://foobar.dk",
+            "http://foobar.museum/foobar",
+            "http://fo.com",
+            "http://FOO.com",
+            "http://foo.com/blah_blah",
+            "http://foo.com/blah_blah/",
+            "http://foo.com/blah_blah_(wikipedia)",
+            "http://foo.com/blah_blah_(wikipedia)_(again)",
+            "http://www.example.com/wpstyle/?p=364",
+            "https://www.example.com/foo/?bar=baz&inga=42&quux",
+            "https://www.example.com?bar=baz",
+            "http://✪df.ws/123",
+            "http://userid:password@example.com:8080",
+            "http://userid@example.com",
+            "http://userid@example.com:8080/",
+            "http://userid:password@example.com",
+            "http://142.42.1.1/",
+            "http://142.42.1.1:8080/",
+            "http://⌘.ws/",
+            "http://foo.com/blah_(wikipedia)#cite-1",
+            "http://foo.com/unicode_(✪)_in_parens",
+            "http://foo.com/(something)?after=parens",
+            "http://☺.damowmow.com/",
+            "http://code.google.com/events/#&product=browser",
+            "http://j.mp",
+            "ftp://foo.bar/baz",
+            "http://foo.bar/?q=Test%20URL-encoded%20stuff",
+            "http://-.~_!$&'()*+,;=:%40:80%2f::::::@example.com",
+            "http://1337.net",
+            "http://a.b-c.de",
+            "http://223.255.255.254",
+            "http://127.0.10.150",
+            "http://localhost",
+            "http://localhost:8000",
+            "http://[FEDC:BA98:7654:3210:FEDC:BA98:7654:3210]:80/index.html",
+            "http://[1080:0:0:0:8:800:200C:417A]/index.html",
+            "http://[3ffe:2a00:100:7031::1]",
+            "http://[1080::8:800:200C:417A]/foo",
+            "http://[::192.9.5.5]/ipng",
+            "http://[::FFFF:129.144.52.38]:80/index.html",
+            "http://[2010:836B:4179::836B:4179]",
         ]
         for address in addresses:
             with self.subTest(address):
-                self.assertTrue(is_url(address),  "should be a valid address: '{}'".format(address))
+                self.assertTrue(is_url(address), f"should be a valid address: '{address}'")
 
     def test_is_url_returns_False_on_failed_url(self):
         failed_addresses = [
@@ -109,10 +108,10 @@ class TestIsURL(SixTestCase):
         ]
         for address in failed_addresses:
             with self.subTest(address):
-                self.assertFalse(is_url(address), "should be a invalid address: '{}'".format(address))
+                self.assertFalse(is_url(address), f"should be a invalid address: '{address}'")
 
 
-class TestIsEmail(SixTestCase):
+class TestIsEmail(TestCase):
     def test_is_email_returns_true_on_valid_url(self):
         valid_addresses = [
             "some@domain.org",
@@ -133,7 +132,7 @@ class TestIsEmail(SixTestCase):
         ]
         for email in valid_addresses:
             with self.subTest(email):
-                self.assertTrue(is_valid_email(email),  "should be a valid address: '{}'".format(email))
+                self.assertTrue(is_valid_email(email), f"should be a valid address: '{email}'")
 
     def test_is_email_returns_false_on_invalid_url(self):
         invalid_addresses = [
@@ -152,17 +151,16 @@ class TestIsEmail(SixTestCase):
             "email@-example.com",
             "email@example..com",
             "Abc..123@example.com",
-            "”(),:;<>[\]@example.com",
+            r"”(),:;<>[\]@example.com",
             "just”not”right@example.com",
-            'this\ is"really"not\allowed@example.com',
+            'this\\ is"really"not\allowed@example.com',
         ]
         for email in invalid_addresses:
             with self.subTest(email):
-                self.assertFalse(is_valid_email(email), "should be an invalid address: '{}'".format(email))
+                self.assertFalse(is_valid_email(email), f"should be an invalid address: '{email}'")
 
 
 class TestEmpty(TestCase):
-
     def test_singleton(self):
         empty_1 = Empty()
         empty_2 = Empty()
@@ -173,7 +171,6 @@ class TestEmpty(TestCase):
 
 
 class TestChunks(TestCase):
-
     def test_get_in_chunks(self):
         chunks = get_in_chunks(
             lst=list(range(77)),
@@ -181,6 +178,7 @@ class TestChunks(TestCase):
         )
 
         import types
+
         self.assertIsInstance(chunks, types.GeneratorType)
 
         chunks_list = list(chunks)
